@@ -17,13 +17,13 @@
 gf_bfs <- function(x,
                    from_expr,
                    to_expr,
-                   max_path_length = 10L,
+                   max_path_length = 10,
                    edge_filter = NULL, ...) {
 
-  from_expr <- ensure_scalar_character(from_expr)
-  to_expr <- ensure_scalar_character(to_expr)
-  max_path_length <- ensure_scalar_integer(max_path_length)
-  edge_filter <- ensure_scalar_character(edge_filter, allow.null = TRUE)
+  from_expr <- cast_string(from_expr)
+  to_expr <- cast_string(to_expr)
+  max_path_length <- cast_scalar_integer(max_path_length)
+  edge_filter <- cast_nullable_string(edge_filter)
 
   gf <- spark_graphframe(x)
 
